summaryrefslogtreecommitdiff
path: root/IntelFrameworkPkg/Include/Protocol/FrameworkFormCallback.h
diff options
context:
space:
mode:
authorlgao4 <lgao4@6f19259b-4bc3-4df7-8a09-765794883524>2009-07-13 09:28:00 +0000
committerlgao4 <lgao4@6f19259b-4bc3-4df7-8a09-765794883524>2009-07-13 09:28:00 +0000
commit108854b2b8599ba8bc7605a9bd2ccacef3211d13 (patch)
tree045e33a16d81c02af8d4598f290a4ee677078bb1 /IntelFrameworkPkg/Include/Protocol/FrameworkFormCallback.h
parent2f6e236c2e1d0e2d0753b2c19fb61ad16b9e2e0a (diff)
downloadedk2-platforms-108854b2b8599ba8bc7605a9bd2ccacef3211d13.tar.xz
Remove unnecessary FRAMEWORK_ prefix in IntelFrameworkPkg definitions for those definitions that don't conflict with ones in UEFI/PI specification.
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@8923 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'IntelFrameworkPkg/Include/Protocol/FrameworkFormCallback.h')
-rw-r--r--IntelFrameworkPkg/Include/Protocol/FrameworkFormCallback.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/IntelFrameworkPkg/Include/Protocol/FrameworkFormCallback.h b/IntelFrameworkPkg/Include/Protocol/FrameworkFormCallback.h
index 875f27c927..e26c02aa5b 100644
--- a/IntelFrameworkPkg/Include/Protocol/FrameworkFormCallback.h
+++ b/IntelFrameworkPkg/Include/Protocol/FrameworkFormCallback.h
@@ -19,8 +19,8 @@
**/
-#ifndef __FORM_CALLBACK_H__
-#define __FORM_CALLBACK_H__
+#ifndef __FRAMEWORK_FORM_CALLBACK_H__
+#define __FRAMEWORK_FORM_CALLBACK_H__
#include <Protocol/FrameworkHii.h>
#include <Protocol/FrameworkFormBrowser.h>
@@ -66,32 +66,32 @@ typedef struct _EFI_FORM_CALLBACK_PROTOCOL EFI_FORM_CALLBACK_PROTOCOL;
#pragma pack(1)
typedef struct {
UINT8 OpCode; ///< Likely a string, numeric, or one-of
- UINT8 Length; ///< Length of the FRAMEWORK_EFI_IFR_DATA_ENTRY packet
+ UINT8 Length; ///< Length of the EFI_IFR_DATA_ENTRY packet
UINT16 Flags; ///< Flags settings to determine what behavior is desired from the browser after the callback
VOID *Data; ///< The data in the form based on the op-code type - this is not a pointer to the data, the data follows immediately
///
/// If the OpCode is a OneOf or Numeric type - Data is a UINT16 value
/// If the OpCode is a String type - Data is a CHAR16[x] type
/// If the OpCode is a Checkbox type - Data is a UINT8 value
/// If the OpCode is a NV Access type - Data is a FRAMEWORK_EFI_IFR_NV_DATA structure
///
-} FRAMEWORK_EFI_IFR_DATA_ENTRY;
+} EFI_IFR_DATA_ENTRY;
typedef struct {
VOID *NvRamMap; ///< If the flag of the op-code specified retrieval of a copy of the NVRAM map,
//
// this is a pointer to a buffer copy
//
- UINT32 EntryCount; ///< How many FRAMEWORK_EFI_IFR_DATA_ENTRY entries
+ UINT32 EntryCount; ///< How many EFI_IFR_DATA_ENTRY entries
//
// FRAMEWORK_EFI_IFR_DATA_ENTRY Data[1]; // The in-line Data entries.
//
-} FRAMEWORK_EFI_IFR_DATA_ARRAY;
+} EFI_IFR_DATA_ARRAY;
typedef union {
- FRAMEWORK_EFI_IFR_DATA_ARRAY DataArray; ///< Primarily used by those who call back to their drivers and use HII as a repository
- FRAMEWORK_EFI_IFR_PACKET DataPacket; ///< Primarily used by those which do not use HII as a repository
+ EFI_IFR_DATA_ARRAY DataArray; ///< Primarily used by those who call back to their drivers and use HII as a repository
+ EFI_IFR_PACKET DataPacket; ///< Primarily used by those which do not use HII as a repository
CHAR16 String[1]; ///< If returning an error - fill the string with null-terminated contents
} EFI_HII_CALLBACK_PACKET;
@@ -102,7 +102,7 @@ typedef struct {
//
// CHAR8 Data[1]; // The Data itself
//
-} FRAMEWORK_EFI_IFR_NV_DATA;
+} EFI_IFR_NV_DATA;
#pragma pack()
//
@@ -199,7 +199,7 @@ EFI_STATUS
(EFIAPI *EFI_FORM_CALLBACK)(
IN EFI_FORM_CALLBACK_PROTOCOL *This,
IN UINT16 KeyValue,
- IN FRAMEWORK_EFI_IFR_DATA_ARRAY *Data,
+ IN EFI_IFR_DATA_ARRAY *Data,
OUT EFI_HII_CALLBACK_PACKET **Packet
);
@@ -66,32 +66,32 @@ typedef struct _EFI_FORM_CALLBACK_PROTOCOL EFI_FORM_CALLBACK_PROTOCOL;
/// If the OpCode is a String type - Data is a CHAR16[x] type
/// If the OpCode is a Checkbox type - Data is a UINT8 value
- /// If the OpCode is a NV Access type - Data is a FRAMEWORK_EFI_IFR_NV_DATA structure
+ /// If the OpCode is a NV Access type - Data is a EFI_IFR_NV_DATA structure
///
@@ -66,32 +66,32 @@ typedef struct _EFI_FORM_CALLBACK_PROTOCOL EFI_FORM_CALLBACK_PROTOCOL;
//
- // FRAMEWORK_EFI_IFR_DATA_ENTRY Data[1]; // The in-line Data entries.
+ // EFI_IFR_DATA_ENTRY Data[1]; // The in-line Data entries.
//